[![Cover](https://github.com/pro-well-plan/opensource_apps/raw/master/resources/pwp-bgd.gif)](https://prowellplan.com)


[![Open Source Love svg2](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/pro-well-plan/torque_drag/blob/master/LICENSE.md)
[![PyPI version](https://badge.fury.io/py/torque-drag.svg)](https://badge.fury.io/py/torque-drag)
[![License: LGPL v3](https://img.shields.io/badge/License-LGPL_v3-blue.svg)](https://www.gnu.org/licenses/lgpl-3.0)
[![Webapp](https://img.shields.io/badge/WebApp-On-green.svg)](https://pwp-opensource.herokuapp.com/)
[![Documentation Status](https://readthedocs.org/projects/torque_drag/badge/?version=latest)](http://torque_drag.readthedocs.io/?badge=latest)
[![Downloads](https://pepy.tech/badge/torque-drag)](https://pepy.tech/project/torque-drag)

## Introduction
torque-drag is a tool to calculate drag forces and torque along the well. Features are added as they
are needed; suggestions and contributions of all kinds are very welcome.

## Documentation

See here for the [complete torque_drag package documentation](https://torque_drag.readthedocs.io/en/latest/).

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Get torque-drag

* Users: Wheels for Python from [PyPI](https://pypi.python.org/pypi/torque-drag/) 
    * `pip install torque_drag`
* Source code from [Github](https://github.com/pro-well-plan/torque_drag)
    * `git clone https://github.com/pro-well-plan/torque_drag`

    
## Contributing

Please read [CONTRIBUTING](CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## History ##
This tool was initially written and is maintained by [Pro Well Plan
AS](http://www.prowellplan.com/) as a free, simple, easy-to-use way to perform
torque and drag calculations along the well that can be tailored to our needs, and as contribution to the
free software community.

## License

This project is licensed under the GNU Lesser General Public License v3.0 - see the [LICENSE](LICENSE.md) file for details


*for further information contact juan@prowellplan.com*

[![](https://user-images.githubusercontent.com/52009346/69100304-2eb3e800-0a5d-11ea-9a3a-8e502af2120b.png)](https://prowellplan.com)
